pub fn get_ticks() -> u64Expand description
Get current timer tick count (from the software tick counter maintained by each architecture’s interrupt handler).
pub fn get_ticks() -> u64Get current timer tick count (from the software tick counter maintained by each architecture’s interrupt handler).