pub fn get_timestamp_secs() -> u64Expand description
Get the current timestamp in seconds since boot.
Computed by dividing the raw hardware tick counter by the platform-specific tick frequency.
pub fn get_timestamp_secs() -> u64Get the current timestamp in seconds since boot.
Computed by dividing the raw hardware tick counter by the platform-specific tick frequency.