pub fn dpms_idle_tick()Expand description
Tick the idle timer (called from the scheduler/timer interrupt).
Increments the idle counter and transitions display state when the timeout is reached.
pub fn dpms_idle_tick()Tick the idle timer (called from the scheduler/timer interrupt).
Increments the idle counter and transitions display state when the timeout is reached.