pub fn dpms_init() -> KernelResult<()>Expand description
Initialize the DPMS subsystem.
Registers the idle timer callback and sets initial display state to On.
pub fn dpms_init() -> KernelResult<()>Initialize the DPMS subsystem.
Registers the idle timer callback and sets initial display state to On.