pub fn dpms_reset_idle()Expand description
Reset the idle timer.
Should be called on every input event (keyboard, mouse, touch) to prevent the display from blanking during active use.
pub fn dpms_reset_idle()Reset the idle timer.
Should be called on every input event (keyboard, mouse, touch) to prevent the display from blanking during active use.