pub fn dpms_set_idle_timeout(seconds: u32)Expand description
Set the DPMS idle timeout in seconds.
The display transitions to Off after this many seconds of no input. Set to 0 to disable idle blanking.
pub fn dpms_set_idle_timeout(seconds: u32)Set the DPMS idle timeout in seconds.
The display transitions to Off after this many seconds of no input. Set to 0 to disable idle blanking.