pub fn dpms_set_state(state: DpmsState) -> KernelResult<()>Expand description
Set the display DPMS state.
Controls the VGA sync signals to transition the display into the requested power state. Returns an error if DPMS is not initialized.
pub fn dpms_set_state(state: DpmsState) -> KernelResult<()>Set the display DPMS state.
Controls the VGA sync signals to transition the display into the requested power state. Returns an error if DPMS is not initialized.