pub fn switch_to_kernel()Expand description
Switch to the full kernel page table.
Called on kernel entry (syscall, interrupt, exception). Restores the full CR3 so the kernel has access to all its mappings.
pub fn switch_to_kernel()Switch to the full kernel page table.
Called on kernel entry (syscall, interrupt, exception). Restores the full CR3 so the kernel has access to all its mappings.