Struct KptiPageTables
Source pub struct KptiPageTables {
pub kernel_cr3: u64,
pub shadow_cr3: u64,
}
Per-process KPTI page table pair.
Physical address of the full kernel L4 table.
shadow_cr3: u64Physical address of the shadow (user-mode) L4 table.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.