pub fn init()Expand description
Reprogram PAT entry 1 from WT to WC.
Must be called early in boot, before any memory is mapped with PAT index 1. No-op if the CPU does not support PAT.
pub fn init()Reprogram PAT entry 1 from WT to WC.
Must be called early in boot, before any memory is mapped with PAT index 1. No-op if the CPU does not support PAT.