pub fn init() -> Result<(), KernelError>Expand description
Initialize the audio subsystem
Sets up the mixer, output pipeline, client manager, and probes for VirtIO-Sound hardware.
pub fn init() -> Result<(), KernelError>Initialize the audio subsystem
Sets up the mixer, output pipeline, client manager, and probes for VirtIO-Sound hardware.