pub fn convert_u8_to_s16(data: &[u8]) -> Vec<i16>Expand description
Convert unsigned 8-bit PCM to signed 16-bit PCM
U8 samples are centered at 128 (silence). This function shifts to signed and scales to 16-bit range.
pub fn convert_u8_to_s16(data: &[u8]) -> Vec<i16>Convert unsigned 8-bit PCM to signed 16-bit PCM
U8 samples are centered at 128 (silence). This function shifts to signed and scales to 16-bit range.