pub struct NodeArena { /* private fields */ }
Arena allocator for DOM nodes
Allocate a new node and return its ID
Get a reference to a node by ID
Get a mutable reference to a node by ID
Number of nodes in the arena
Check if arena is empty
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U