pub fn handle_click_on_link(href: &str) -> LinkActionExpand description
Extract href from a link node and determine navigation action
pub fn handle_click_on_link(href: &str) -> LinkActionExtract href from a link node and determine navigation action