⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

ProcessIsolation

Struct ProcessIsolation 

pub struct ProcessIsolation { /* private fields */ }
Manages all tab processes and their isolation

Implementations

Source

impl ProcessIsolation

pub fn new() -> Self

pub fn spawn_tab_process(&mut self, tab_id: TabId) -> Result<(), TabError>

Spawn a new tab process

pub fn spawn_with_capabilities( &mut self, tab_id: TabId, capabilities: TabCapabilities, ) -> Result<(), TabError>

Spawn with custom capabilities

pub fn kill_tab_process(&mut self, tab_id: TabId) -> bool

Kill a tab process

pub fn recover_from_crash(&mut self, tab_id: TabId) -> Result<(), TabError>

Recover a crashed tab process (recreate its context)

pub fn restrict_capabilities( &mut self, tab_id: TabId, capabilities: TabCapabilities, ) -> bool

Restrict capabilities for a tab

pub fn get_process(&self, tab_id: TabId) -> Option<&TabProcess>

Get a tab process

pub fn get_process_mut(&mut self, tab_id: TabId) -> Option<&mut TabProcess>

Get a tab process mutably

pub fn post_message( &mut self, source: TabId, target: TabId, data: &str, ) -> Result<(), TabError>

Send postMessage from one tab to another

pub fn subscribe_broadcast(&mut self, tab_id: TabId, channel: &str) -> bool

Subscribe a tab to a broadcast channel

pub fn unsubscribe_broadcast(&mut self, tab_id: TabId, channel: &str)

Unsubscribe a tab from a broadcast channel

pub fn broadcast_message( &mut self, source: TabId, channel: &str, data: &str, ) -> usize

Send a broadcast message to all subscribers of a channel

pub fn storage_set(&mut self, origin: &str, key: &str, value: &str)

Set a value in shared storage for an origin

pub fn storage_get(&self, origin: &str, key: &str) -> Option<&String>

Get a value from shared storage

pub fn storage_remove(&mut self, origin: &str, key: &str) -> Option<String>

Remove a value from shared storage

pub fn tick_all(&mut self)

Tick all running processes

pub fn suspend_background_tabs(&mut self, active_tab: TabId)

Suspend all background tab processes

pub fn resume_tab(&mut self, tab_id: TabId) -> bool

Resume a specific tab process

pub fn active_count(&self) -> usize

Number of active processes

pub fn total_count(&self) -> usize

Total number of processes

pub fn total_crashes(&self) -> usize

Total crashes across all tabs

pub fn resource_usage(&self, tab_id: TabId) -> Option<&ResourceUsage>

Get resource usage for a tab

pub fn aggregate_usage(&self) -> ResourceUsage

Get aggregate resource usage across all tabs