⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

Tab

Struct Tab 

pub struct Tab {
    pub id: TabId,
    pub title: String,
    pub url: String,
    pub active: bool,
    pub load_state: TabLoadState,
    pub favicon: Option<Vec<u8>>,
    pub history: NavigationHistory,
    pub dirty: bool,
    pub pinned: bool,
    pub creation_order: u64,
    pub last_active_tick: u64,
    pub error_message: Option<String>,
}
A single browser tab

Fields

id: TabId

Unique tab identifier

title: String

Tab title (from tag or URL)</p> </div><span id="structfield.url" class="structfield section-header"><a href="#structfield.url" class="anchor field"></a><code>url: String</code></span><div class="docblock"><p>Current URL</p> </div><span id="structfield.active" class="structfield section-header"><a href="#structfield.active" class="anchor field"></a><code>active: bool</code></span><div class="docblock"><p>Whether this tab is the active (visible) tab</p> </div><span id="structfield.load_state" class="structfield section-header"><a href="#structfield.load_state" class="anchor field"></a><code>load_state: <a class="enum" href="enum.TabLoadState.html" title="enum veridian_kernel::browser::tabs::TabLoadState">TabLoadState</a></code></span><div class="docblock"><p>Loading state</p> </div><span id="structfield.favicon" class="structfield section-header"><a href="#structfield.favicon" class="anchor field"></a><code>favicon: Option<Vec<u8>></code></span><div class="docblock"><p>Favicon data (raw pixel bytes, 16x16 BGRA)</p> </div><span id="structfield.history" class="structfield section-header"><a href="#structfield.history" class="anchor field"></a><code>history: <a class="struct" href="struct.NavigationHistory.html" title="struct veridian_kernel::browser::tabs::NavigationHistory">NavigationHistory</a></code></span><div class="docblock"><p>Navigation history</p> </div><span id="structfield.dirty" class="structfield section-header"><a href="#structfield.dirty" class="anchor field"></a><code>dirty: bool</code></span><div class="docblock"><p>Whether the tab has been modified (e.g., form data)</p> </div><span id="structfield.pinned" class="structfield section-header"><a href="#structfield.pinned" class="anchor field"></a><code>pinned: bool</code></span><div class="docblock"><p>Whether the tab is pinned</p> </div><span id="structfield.creation_order" class="structfield section-header"><a href="#structfield.creation_order" class="anchor field"></a><code>creation_order: u64</code></span><div class="docblock"><p>Tab creation order (for sorting)</p> </div><span id="structfield.last_active_tick" class="structfield section-header"><a href="#structfield.last_active_tick" class="anchor field"></a><code>last_active_tick: u64</code></span><div class="docblock"><p>Last active timestamp (tick count)</p> </div><span id="structfield.error_message" class="structfield section-header"><a href="#structfield.error_message" class="anchor field"></a><code>error_message: Option<String></code></span><div class="docblock"><p>Optional error message</p> </div><h2 id="implementations" class="section-header">Implementations<a href="#implementations" class="anchor"></a></h2><div id="implementations-list"><details class="toggle implementors-toggle" open><summary><section id="impl-Tab" class="impl"><a class="src rightside" href="../../../src/veridian_kernel/browser/tabs.rs.html#165-254">Source</a><a href="#impl-Tab" class="anchor"></a><h3 class="code-header">impl <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section></summary><div class="impl-items"><section id="method.new" class="method"><a class="src rightside" href="../../../src/veridian_kernel/browser/tabs.rs.html#166-185">Source</a><h4 class="code-header">pub fn <a href="#method.new" class="fn">new</a>(id: <a class="type" href="type.TabId.html" title="type veridian_kernel::browser::tabs::TabId">TabId</a>, url: &str, creation_order: u64) -> Self</h4></section></div></details></div><h2 id="trait-implementations" class="section-header">Trait Implementations<a href="#trait-implementations" class="anchor"></a></h2><div id="trait-implementations-list"><details class="toggle implementors-toggle" open><summary><section id="impl-Clone-for-Tab" class="impl"><a class="src rightside" href="../../../src/veridian_kernel/browser/tabs.rs.html#137">Source</a><a href="#impl-Clone-for-Tab" class="anchor"></a><h3 class="code-header">impl Clone for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.clone" class="method trait-impl"><a class="src rightside" href="../../../src/veridian_kernel/browser/tabs.rs.html#137">Source</a><a href="#method.clone" class="anchor"></a><h4 class="code-header">fn <a class="fn">clone</a>(&self) -> <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h4></section></summary><div class='docblock'>Returns a duplicate of the value. <a>Read more</a></div></details><details class="toggle method-toggle" open><summary><section id="method.clone_from" class="method trait-impl"><span class="since rightside" title="Stable since Rust version 1.0.0">1.0.0</span><a href="#method.clone_from" class="anchor"></a><h4 class="code-header">fn <a class="fn">clone_from</a>(&mut self, source: &Self)</h4></section></summary><div class='docblock'>Performs copy-assignment from <code>source</code>. <a>Read more</a></div></details></div></details></div><h2 id="synthetic-implementations" class="section-header">Auto Trait Implementations<a href="#synthetic-implementations" class="anchor"></a></h2><div id="synthetic-implementations-list"><section id="impl-Freeze-for-Tab" class="impl"><a href="#impl-Freeze-for-Tab" class="anchor"></a><h3 class="code-header">impl Freeze for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section><section id="impl-RefUnwindSafe-for-Tab" class="impl"><a href="#impl-RefUnwindSafe-for-Tab" class="anchor"></a><h3 class="code-header">impl RefUnwindSafe for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section><section id="impl-Send-for-Tab" class="impl"><a href="#impl-Send-for-Tab" class="anchor"></a><h3 class="code-header">impl Send for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section><section id="impl-Sync-for-Tab" class="impl"><a href="#impl-Sync-for-Tab" class="anchor"></a><h3 class="code-header">impl Sync for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section><section id="impl-Unpin-for-Tab" class="impl"><a href="#impl-Unpin-for-Tab" class="anchor"></a><h3 class="code-header">impl Unpin for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section><section id="impl-UnwindSafe-for-Tab" class="impl"><a href="#impl-UnwindSafe-for-Tab" class="anchor"></a><h3 class="code-header">impl UnwindSafe for <a class="struct" href="struct.Tab.html" title="struct veridian_kernel::browser::tabs::Tab">Tab</a></h3></section></div><h2 id="blanket-implementations" class="section-header">Blanket Implementations<a href="#blanket-implementations" class="anchor"></a></h2><div id="blanket-implementations-list"><details class="toggle implementors-toggle"><summary><section id="impl-Any-for-T" class="impl"><a href="#impl-Any-for-T" class="anchor"></a><h3 class="code-header">impl<T> Any for T<div class="where">where T: 'static + ?Sized,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.type_id" class="method trait-impl"><a href="#method.type_id" class="anchor"></a><h4 class="code-header">fn <a class="fn">type_id</a>(&self) -> TypeId</h4></section></summary><div class='docblock'>Gets the <code>TypeId</code> of <code>self</code>. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-Borrow%3CT%3E-for-T" class="impl"><a href="#impl-Borrow%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> Borrow<T> for T<div class="where">where T: ?Sized,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.borrow" class="method trait-impl"><a href="#method.borrow" class="anchor"></a><h4 class="code-header">fn <a class="fn">borrow</a>(&self) -> &T</h4></section></summary><div class='docblock'>Immutably borrows from an owned value. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-BorrowMut%3CT%3E-for-T" class="impl"><a href="#impl-BorrowMut%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> BorrowMut<T> for T<div class="where">where T: ?Sized,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.borrow_mut" class="method trait-impl"><a href="#method.borrow_mut" class="anchor"></a><h4 class="code-header">fn <a class="fn">borrow_mut</a>(&mut self) -> &mut T</h4></section></summary><div class='docblock'>Mutably borrows from an owned value. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-CloneToUninit-for-T" class="impl"><a href="#impl-CloneToUninit-for-T" class="anchor"></a><h3 class="code-header">impl<T> CloneToUninit for T<div class="where">where T: Clone,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.clone_to_uninit" class="method trait-impl"><a href="#method.clone_to_uninit" class="anchor"></a><h4 class="code-header">unsafe fn <a class="fn">clone_to_uninit</a>(&self, dest: *mut u8)</h4></section></summary><span class="item-info"><div class="stab unstable"><span class="emoji">🔬</span><span>This is a nightly-only experimental API. (<code>clone_to_uninit</code>)</span></div></span><div class='docblock'>Performs copy-assignment from <code>self</code> to <code>dest</code>. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-From%3CT%3E-for-T" class="impl"><a href="#impl-From%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> From<T> for T</h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.from" class="method trait-impl"><a href="#method.from" class="anchor"></a><h4 class="code-header">fn <a class="fn">from</a>(t: T) -> T</h4></section></summary><div class="docblock"><p>Returns the argument unchanged.</p> </div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-Into%3CU%3E-for-T" class="impl"><a href="#impl-Into%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> Into<U> for T<div class="where">where U: From<T>,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.into" class="method trait-impl"><a href="#method.into" class="anchor"></a><h4 class="code-header">fn <a class="fn">into</a>(self) -> U</h4></section></summary><div class="docblock"><p>Calls <code>U::from(self)</code>.</p> <p>That is, this conversion is whatever the implementation of <code>[From]<T> for U</code> chooses to do.</p> </div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-ToOwned-for-T" class="impl"><a href="#impl-ToOwned-for-T" class="anchor"></a><h3 class="code-header">impl<T> ToOwned for T<div class="where">where T: Clone,</div></h3></section></summary><div class="impl-items"><details class="toggle" open><summary><section id="associatedtype.Owned" class="associatedtype trait-impl"><a href="#associatedtype.Owned" class="anchor"></a><h4 class="code-header">type <a class="associatedtype">Owned</a> = T</h4></section></summary><div class='docblock'>The resulting type after obtaining ownership.</div></details><details class="toggle method-toggle" open><summary><section id="method.to_owned" class="method trait-impl"><a href="#method.to_owned" class="anchor"></a><h4 class="code-header">fn <a class="fn">to_owned</a>(&self) -> T</h4></section></summary><div class='docblock'>Creates owned data from borrowed data, usually by cloning. <a>Read more</a></div></details><details class="toggle method-toggle" open><summary><section id="method.clone_into" class="method trait-impl"><a href="#method.clone_into" class="anchor"></a><h4 class="code-header">fn <a class="fn">clone_into</a>(&self, target: &mut T)</h4></section></summary><div class='docblock'>Uses borrowed data to replace owned data, usually by cloning. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFrom%3CU%3E-for-T" class="impl"><a href="#impl-TryFrom%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> TryFrom<U> for T<div class="where">where U: Into<T>,</div></h3></section></summary><div class="impl-items"><details class="toggle" open><summary><section id="associatedtype.Error-1" class="associatedtype trait-impl"><a href="#associatedtype.Error-1" class="anchor"></a><h4 class="code-header">type <a class="associatedtype">Error</a> = Infallible</h4></section></summary><div class='docblock'>The type returned in the event of a conversion error.</div></details><details class="toggle method-toggle" open><summary><section id="method.try_from" class="method trait-impl"><a href="#method.try_from" class="anchor"></a><h4 class="code-header">fn <a class="fn">try_from</a>(value: U) -> Result<T, <T as TryFrom<U>>::Error></h4></section></summary><div class='docblock'>Performs the conversion.</div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryInto%3CU%3E-for-T" class="impl"><a href="#impl-TryInto%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> TryInto<U> for T<div class="where">where U: TryFrom<T>,</div></h3></section></summary><div class="impl-items"><details class="toggle" open><summary><section id="associatedtype.Error" class="associatedtype trait-impl"><a href="#associatedtype.Error" class="anchor"></a><h4 class="code-header">type <a class="associatedtype">Error</a> = <U as TryFrom<T>>::Error</h4></section></summary><div class='docblock'>The type returned in the event of a conversion error.</div></details><details class="toggle method-toggle" open><summary><section id="method.try_into" class="method trait-impl"><a href="#method.try_into" class="anchor"></a><h4 class="code-header">fn <a class="fn">try_into</a>(self) -> Result<U, <U as TryFrom<T>>::Error></h4></section></summary><div class='docblock'>Performs the conversion.</div></details></div></details></div></section></div></main><!-- Footer content for all documentation pages --> <footer class="veridian-footer"> <hr> <p> <strong>VeridianOS</strong> - A next-generation microkernel operating system<br> <a href="https://github.com/doublegate/VeridianOS">GitHub</a> | <a href="/docs/architecture/">Architecture Guide</a> | <a href="/docs/contributing/">Contributing</a> </p> </footer> </body></html>