pub fn char_width(ch: char) -> u8Expand description
Get the display width of a character in terminal cells.
Returns 2 for wide (CJK) characters, 0 for zero-width characters (combining marks, control chars), and 1 for everything else.
pub fn char_width(ch: char) -> u8Get the display width of a character in terminal cells.
Returns 2 for wide (CJK) characters, 0 for zero-width characters (combining marks, control chars), and 1 for everything else.