pub fn with_notification_manager<R, F: FnOnce(&mut NotificationManager) -> R>(
f: F,
) -> Option<R>Expand description
Execute a closure with a mutable reference to the notification manager.
pub fn with_notification_manager<R, F: FnOnce(&mut NotificationManager) -> R>(
f: F,
) -> Option<R>Execute a closure with a mutable reference to the notification manager.