pub fn with_system_tray<R, F: FnOnce(&mut SystemTray) -> R>(f: F) -> Option<R>Expand description
Execute a closure with a mutable reference to the system tray.
pub fn with_system_tray<R, F: FnOnce(&mut SystemTray) -> R>(f: F) -> Option<R>Execute a closure with a mutable reference to the system tray.