pub fn with_system_tray_ref<R, F: FnOnce(&SystemTray) -> R>(f: F) -> Option<R>Expand description
Execute a closure with a shared reference to the system tray.
pub fn with_system_tray_ref<R, F: FnOnce(&SystemTray) -> R>(f: F) -> Option<R>Execute a closure with a shared reference to the system tray.