pub struct IdleInhibitor {
pub id: u32,
pub surface_id: u32,
pub active: bool,
}Expand description
An idle inhibitor tied to a specific surface.
While active, prevents the system from entering idle state (e.g., dimming the screen or activating a screen locker). The inhibitor is automatically deactivated when its associated surface is destroyed or unmapped.
Fields
id: u32Inhibitor object ID
surface_id: u32Surface ID that this inhibitor is tied to
active: boolWhether this inhibitor is currently active