Struct Workspace
Source pub struct Workspace {
pub id: WorkspaceId,
pub name: [u8; 32],
pub name_len: usize,
pub windows: Vec<WindowId>,
}
Virtual workspace containing a set of windows
Get workspace name as string slice
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.