pub fn init() -> Result<(), KernelError>Expand description
Initialize the Bluetooth device node subsystem.
Creates the /dev/bluetooth/hci0 device node entry.
Must be called after the Bluetooth controller is initialized.
pub fn init() -> Result<(), KernelError>Initialize the Bluetooth device node subsystem.
Creates the /dev/bluetooth/hci0 device node entry.
Must be called after the Bluetooth controller is initialized.