pub fn push_event(event: InputEvent)Expand description
Push an input event into the global event queue.
Called by keyboard and mouse drivers.
pub fn push_event(event: InputEvent)Push an input event into the global event queue.
Called by keyboard and mouse drivers.