pub fn get_console_terminal() -> Option<&'static Mutex<TerminalState>>Expand description
Get the global console terminal state.
Returns None if the terminal subsystem has not been initialized.
pub fn get_console_terminal() -> Option<&'static Mutex<TerminalState>>Get the global console terminal state.
Returns None if the terminal subsystem has not been initialized.