pub fn get_vtime() -> u8Expand description
Get the VTIME value from the console terminal state.
VTIME specifies the timeout in tenths of a second for non-canonical read. Default is 0 (no timeout, block until VMIN characters).
pub fn get_vtime() -> u8Get the VTIME value from the console terminal state.
VTIME specifies the timeout in tenths of a second for non-canonical read. Default is 0 (no timeout, block until VMIN characters).