pub fn usb_hotplug_init(portsc_base: usize, num_ports: u8)Expand description
Initialize USB hotplug detection
Should be called after xHCI controller enumeration, with the PORTSC base address and number of root hub ports.
pub fn usb_hotplug_init(portsc_base: usize, num_ports: u8)Initialize USB hotplug detection
Should be called after xHCI controller enumeration, with the PORTSC base address and number of root hub ports.