pub fn flush_framebuffer() -> Result<(), KernelError>Expand description
Flush the VirtIO GPU framebuffer to the display.
Convenience function that acquires the driver lock and flushes.
pub fn flush_framebuffer() -> Result<(), KernelError>Flush the VirtIO GPU framebuffer to the display.
Convenience function that acquires the driver lock and flushes.