⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

attach_virtio_backend

Function attach_virtio_backend 

pub fn attach_virtio_backend(fs: &BlockFs, load_from_disk: bool) -> bool
Try to attach the virtio-blk device as a disk backend for the given BlockFS instance. Returns true if a device was found and attached.

This should be called after both the BlockFS and virtio-blk driver have been initialized.