pub fn inotify_pending(instance_id: u64) -> Result<usize, KernelError>Expand description
Check how many events are pending for an inotify instance.
pub fn inotify_pending(instance_id: u64) -> Result<usize, KernelError>Check how many events are pending for an inotify instance.