Struct NfsMountPoint
Source pub struct NfsMountPoint {
pub mount_path: String,
pub export_path: String,
pub client: NfsClient,
}
NFS mount point for VFS integration.
Path where NFS share is mounted.
NFS export path on the server.
NFS client for this mount.
Create a new NFS mount point.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.