⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

PtySlaveNode

Struct PtySlaveNode 

pub struct PtySlaveNode { /* private fields */ }
VfsNode adapter for the slave side of a PTY.

Reading from this node returns bytes that the master has written (i.e. keyboard input forwarded to the shell). Writing to this node sends bytes to the master’s output buffer (the program’s output visible in the terminal emulator).

Implementations

Source

impl PtySlaveNode

pub fn new(slave: PtySlave) -> Self

Wrap a PtySlave as a VfsNode.

pub fn pty_id(&self) -> u32

Return the PTY ID of this slave.

pub fn pts_path(&self) -> String

Return the path that would be exposed as the slave device name.