⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

deliver_signal

Function deliver_signal 

pub fn deliver_signal(target_pid: u64, signum: u32, sender_pid: u32)
Deliver a signal to all signalfds of a given process that have the signal in their mask.

Called from the kernel’s signal delivery path.