pub fn cleanup_inode_xattrs(inode: u64)Expand description
Remove all extended attributes for an inode.
Intended to be called when an inode is deleted. This is a no-op if the inode has no attributes.
pub fn cleanup_inode_xattrs(inode: u64)Remove all extended attributes for an inode.
Intended to be called when an inode is deleted. This is a no-op if the inode has no attributes.