pub fn count_xattrs(inode: u64) -> usizeExpand description
Return the number of attributes currently stored for inode.
Returns 0 if the inode has no attributes.
pub fn count_xattrs(inode: u64) -> usizeReturn the number of attributes currently stored for inode.
Returns 0 if the inode has no attributes.