pub fn listxattr(inode: u64) -> Result<Vec<String>, KernelError>Expand description
List all extended attribute names for an inode.
Returns an empty vector if the inode has no attributes.
pub fn listxattr(inode: u64) -> Result<Vec<String>, KernelError>List all extended attribute names for an inode.
Returns an empty vector if the inode has no attributes.