pub fn removexattr(inode: u64, name: &str) -> Result<(), KernelError>Expand description
Remove a single extended attribute.
Returns an error if the attribute does not exist.
pub fn removexattr(inode: u64, name: &str) -> Result<(), KernelError>Remove a single extended attribute.
Returns an error if the attribute does not exist.