pub fn enable_output()Expand description
Enable fbcon output. Called after boot completes (just before the shell launches) so that the hundreds of boot log lines don’t get rendered pixel-by-pixel to the framebuffer in QEMU.
pub fn enable_output()Enable fbcon output. Called after boot completes (just before the shell launches) so that the hundreds of boot log lines don’t get rendered pixel-by-pixel to the framebuffer in QEMU.