pub fn mark_all_dirty_and_flush()Expand description
Mark all rows dirty and trigger a full blit on the next flush.
Used when returning from GUI mode to repaint the entire text console.
pub fn mark_all_dirty_and_flush()Mark all rows dirty and trigger a full blit on the next flush.
Used when returning from GUI mode to repaint the entire text console.