Struct VirglContext
Source pub struct VirglContext {
pub ctx_id: u32,
pub name: [u8; 64],
pub name_len: usize,
pub resources: Vec<u32>,
pub active: bool,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.