pub fn fast_ipc_send(msg: &SmallMessage, target: ProcessId) -> Result<()>Expand description
Fast-path IPC for small messages
This function implements the register-based fast path for messages that fit entirely in CPU registers.
pub fn fast_ipc_send(msg: &SmallMessage, target: ProcessId) -> Result<()>Fast-path IPC for small messages
This function implements the register-based fast path for messages that fit entirely in CPU registers.