pub fn shm_close(name: &str) -> KernelResult<()>Expand description
Close a reference to a shared memory object.
Decrements the reference count. If the object was unlinked and this was the last reference, the backing memory is freed.
pub fn shm_close(name: &str) -> KernelResult<()>Close a reference to a shared memory object.
Decrements the reference count. If the object was unlinked and this was the last reference, the backing memory is freed.