pub fn create_endpoint(owner: ProcessId) -> Result<(EndpointId, IpcCapability)>Expand description
Global registry access functions Create an endpoint through the global registry
pub fn create_endpoint(owner: ProcessId) -> Result<(EndpointId, IpcCapability)>Global registry access functions Create an endpoint through the global registry