Struct SyncStatsSummary
Source pub struct SyncStatsSummary {
pub send_count: u64,
pub receive_count: u64,
pub fast_path_count: u64,
pub slow_path_count: u64,
pub avg_latency_cycles: u64,
pub fast_path_percentage: u64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.