Struct ZeroCopyStatsSummary
Source pub struct ZeroCopyStatsSummary {
pub pages_transferred: u64,
pub bytes_transferred: u64,
pub transfer_count: u64,
pub avg_remap_cycles: u64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.