pub fn log_count() -> Option<usize>Expand description
Return the number of entries currently in the log buffer.
Returns None if the service is not initialized.
pub fn log_count() -> Option<usize>Return the number of entries currently in the log buffer.
Returns None if the service is not initialized.