macro_rules! kprint {
($lit:literal) => { ... };
($($arg:tt)*) => { ... };
}Expand description
Print a string literal to the kernel console (all architectures). For formatted output, works on x86_64 and RISC-V only; no-op on AArch64.
macro_rules! kprint {
($lit:literal) => { ... };
($($arg:tt)*) => { ... };
}Print a string literal to the kernel console (all architectures). For formatted output, works on x86_64 and RISC-V only; no-op on AArch64.