pub struct AudioSchedStats {
pub periods_completed: u64,
pub on_time_wakes: u64,
pub late_wakes: u64,
pub underruns: u64,
pub overruns: u64,
pub max_jitter_ns: u64,
pub min_jitter_ns: u64,
pub total_jitter_ns: u64,
pub last_wake_ns: u64,
pub next_expected_wake_ns: u64,
}Expand description
Statistics for a single audio thread’s scheduling behavior.
Fields
periods_completed: u64Total number of scheduling periods completed.
on_time_wakes: u64Number of times the thread was woken on time.
late_wakes: u64Number of times the thread was woken late (missed deadline).
underruns: u64Number of buffer underruns (thread did not fill buffer in time).
overruns: u64Number of buffer overruns (buffer full, data lost).
max_jitter_ns: u64Maximum observed scheduling jitter in nanoseconds.
min_jitter_ns: u64Minimum observed scheduling jitter in nanoseconds.
total_jitter_ns: u64Cumulative jitter (for computing average).
last_wake_ns: u64Last wake timestamp (nanoseconds since boot).
next_expected_wake_ns: u64Expected next wake timestamp.