Struct CowEntry
Source pub struct CowEntry {
pub frame: FrameNumber,
pub ref_count: AtomicU32,
}
A single COW-shared physical frame.
The shared physical frame.
Number of address spaces sharing this frame.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.