Struct CowTable
Source pub struct CowTable {
pub entries: BTreeMap<usize, CowEntry>,
}
Table of COW-shared frames keyed by virtual page address.
Map from virtual page address to COW entry.
Create an empty COW table.
Register a frame as COW-shared with initial ref_count = 2.
Decrement ref count for a COW page; returns true if this was the
last reference (frame can be freed).
Check whether an address is COW-tracked.
SourceAvailable on crate feature alloc only.
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.