pub struct PageTableEntry { /* private fields */ }Expand description
Page table entry
Implementations
Sourceimpl PageTableEntry
impl PageTableEntry
Sourcepub const fn is_present(&self) -> bool
pub const fn is_present(&self) -> bool
Check if the entry is present
Sourcepub fn frame(&self) -> Option<FrameNumber>
pub fn frame(&self) -> Option<FrameNumber>
Get the physical frame this entry points to
Sourcepub fn addr(&self) -> Option<PhysicalAddress>
pub fn addr(&self) -> Option<PhysicalAddress>
Get the address this entry points to
Sourcepub fn set(&mut self, frame: FrameNumber, flags: PageFlags)
pub fn set(&mut self, frame: FrameNumber, flags: PageFlags)
Set this entry to map to a frame with given flags
Sourcepub fn set_addr(&mut self, addr: PhysicalAddress, flags: PageFlags)
pub fn set_addr(&mut self, addr: PhysicalAddress, flags: PageFlags)
Set this entry to map to an address with given flags