Struct VasStats
Source pub struct VasStats {
pub total_size: usize,
pub code_size: usize,
pub data_size: usize,
pub stack_size: usize,
pub heap_size: usize,
pub mapping_count: usize,
}
Virtual address space statistics
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.