pub enum BondError {
BondAlreadyExists,
BondNotFound,
SlaveAlreadyExists,
SlaveNotFound,
NoSlavesAvailable,
NotInitialized,
}Expand description
Errors returned by bonding operations
Variants
BondAlreadyExists
Bond with the given name already exists
BondNotFound
Bond with the given name was not found
SlaveAlreadyExists
Slave with the given name already exists in the bond
SlaveNotFound
Slave with the given name was not found in the bond
NoSlavesAvailable
No slaves available for transmission
NotInitialized
Bond manager not initialized