pub fn with_device<R, F: FnOnce(&dyn NetworkDevice) -> R>(
name: &str,
f: F,
) -> Option<R>Expand description
Execute a closure with a device by name (immutable access)
pub fn with_device<R, F: FnOnce(&dyn NetworkDevice) -> R>(
name: &str,
f: F,
) -> Option<R>Execute a closure with a device by name (immutable access)