pub fn dispatch_frame(
data: &[u8],
our_mac: &MacAddress,
) -> Result<(), KernelError>Expand description
Dispatch a received Ethernet frame to the appropriate protocol handler.
Routes frames to ARP or IP based on the EtherType field.
pub fn dispatch_frame(
data: &[u8],
our_mac: &MacAddress,
) -> Result<(), KernelError>Dispatch a received Ethernet frame to the appropriate protocol handler.
Routes frames to ARP or IP based on the EtherType field.