⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

RuleEngine

Struct RuleEngine 

pub struct RuleEngine { /* private fields */ }
Manages all firewall rules and provides lookup by ID

Implementations

Source

impl RuleEngine

pub fn new() -> Self

Create a new empty rule engine

pub fn add_rule(&mut self, rule: FirewallRule) -> u64

Add a rule and return its assigned ID

pub fn remove_rule(&mut self, id: u64) -> Option<FirewallRule>

Remove a rule by ID

pub fn get_rule(&self, id: u64) -> Option<&FirewallRule>

Get a rule by ID (immutable)

pub fn get_rule_mut(&mut self, id: u64) -> Option<&mut FirewallRule>

Get a rule by ID (mutable)

pub fn rule_count(&self) -> usize

Number of rules

pub fn evaluate( &mut self, rule_ids: &[u64], metadata: &PacketMetadata, ) -> Option<RuleAction>

Evaluate a packet against a list of rule IDs, returning the first matching rule’s action

pub fn rules_by_priority(&self) -> Vec<&FirewallRule>

Get all rules sorted by priority