pub fn format_ipv6_compressed(addr: &Ipv6Address) -> StringExpand description
Format an IPv6 address with zero-compression (::).
Finds the longest run of consecutive zero groups and replaces it with “::”.
pub fn format_ipv6_compressed(addr: &Ipv6Address) -> StringFormat an IPv6 address with zero-compression (::).
Finds the longest run of consecutive zero groups and replaces it with “::”.