pub fn parse_ipv6(data: &[u8]) -> Result<(Ipv6Header, &[u8]), KernelError>Expand description
Parse an IPv6 packet from raw bytes.
Returns the parsed header and a slice of the payload data.
pub fn parse_ipv6(data: &[u8]) -> Result<(Ipv6Header, &[u8]), KernelError>Parse an IPv6 packet from raw bytes.
Returns the parsed header and a slice of the payload data.