Enum SearchResult
Source pub enum SearchResult {
Entry(SearchEntry),
Done(LdapResultCode),
}
Result from parsing a search response message.
Search is complete with the given result code
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.