pub fn queue_pending_connection(
addr: SocketAddr,
remote: SocketAddr,
seq_num: u32,
) -> Result<(), KernelError>Expand description
Queue a new connection to a listening socket (called by TCP layer)
pub fn queue_pending_connection(
addr: SocketAddr,
remote: SocketAddr,
seq_num: u32,
) -> Result<(), KernelError>Queue a new connection to a listening socket (called by TCP layer)