Struct ClientHello
Source pub struct ClientHello {
pub random: [u8; 32],
pub session_id: [u8; 32],
pub cipher_suites: Vec<CipherSuite>,
pub key_share_public: [u8; 32],
}
ClientHello message builder
random: [u8; 32]
Encode ClientHello to handshake message bytes
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.