Struct FragmentBuffer
Source pub struct FragmentBuffer { }
Fragment reassembly buffer for handshake messages that span multiple records
Append a record fragment. Returns the reassembled message when complete.
Reset the fragment buffer
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.