pub fn socket_accept(listen_socket_id: u64) -> KernelResult<(u64, u64)>Expand description
Accept a pending connection on a listening socket.
Creates a new connected socket and returns its ID along with the connecting socket’s ID.
pub fn socket_accept(listen_socket_id: u64) -> KernelResult<(u64, u64)>Accept a pending connection on a listening socket.
Creates a new connected socket and returns its ID along with the connecting socket’s ID.