Struct PacketIdWindow
Source pub struct PacketIdWindow { }
Sliding-window anti-replay protection for packet IDs
Create a new anti-replay window
Check whether a packet ID is acceptable (not replayed)
Record a packet ID as seen and advance the window if needed
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.