Struct DmaBufferPool
Source pub struct DmaBufferPool { }
DMA buffer pool for zero-copy operations
Create new DMA buffer pool
Allocate a buffer from the pool
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.