pub struct TrustedKeyRing { /* private fields */ }Expand description
Collection of trusted Ed25519 signing keys.
The package manager iterates over these keys when verifying a package signature, accepting the first key whose Ed25519 verification succeeds.
Implementations
Sourceimpl TrustedKeyRing
impl TrustedKeyRing
Sourcepub fn with_builtin_keys() -> Self
pub fn with_builtin_keys() -> Self
Create a key ring pre-populated with the built-in test key.
The built-in key is a deterministic test key for development. Production builds MUST replace this with keys from a real key ceremony.
Sourcepub fn add_key(&mut self, key: TrustedKey)
pub fn add_key(&mut self, key: TrustedKey)
Add a trusted key to the ring.
Sourcepub fn find_key(&self, public_key: &[u8; 32]) -> Option<&TrustedKey>
pub fn find_key(&self, public_key: &[u8; 32]) -> Option<&TrustedKey>
Find the first key whose public key bytes match.
Sourcepub fn find_by_fingerprint(&self, fingerprint: &[u8; 32]) -> Option<&TrustedKey>
pub fn find_by_fingerprint(&self, fingerprint: &[u8; 32]) -> Option<&TrustedKey>
Find a key by its SHA-256 fingerprint.
Sourcepub fn remove_key(&mut self, fingerprint: &[u8; 32])
pub fn remove_key(&mut self, fingerprint: &[u8; 32])
Remove keys matching the given fingerprint.
Sourcepub fn keys(&self) -> &[TrustedKey]
pub fn keys(&self) -> &[TrustedKey]
Iterate over all trusted keys.