pub struct ToolchainRegistry { /* private fields */ }Expand description
Registry of known toolchains, keyed by name.
Implementations
Sourceimpl ToolchainRegistry
impl ToolchainRegistry
Sourcepub fn register(&mut self, toolchain: Toolchain) -> KernelResult<()>
pub fn register(&mut self, toolchain: Toolchain) -> KernelResult<()>
Register a toolchain. Returns an error if a toolchain with the same name is already registered.
Sourcepub fn remove(&mut self, name: &str) -> KernelResult<Toolchain>
pub fn remove(&mut self, name: &str) -> KernelResult<Toolchain>
Remove a toolchain by name. Returns an error if it does not exist.
Sourcepub fn set_default(&mut self, name: &str) -> KernelResult<()>
pub fn set_default(&mut self, name: &str) -> KernelResult<()>
Set the default toolchain by name. The toolchain must already be registered.
Sourcepub fn get_default(&self) -> Option<&Toolchain>
pub fn get_default(&self) -> Option<&Toolchain>
Return a reference to the default toolchain, if one has been set.