pub fn init()Expand description
Initialize process management subsystem (legacy)
This creates the init process, so scheduler must be initialized first.
pub fn init()Initialize process management subsystem (legacy)
This creates the init process, so scheduler must be initialized first.