#[repr(u8)]pub enum ThreadState {
Creating = 0,
Ready = 1,
Running = 2,
Blocked = 3,
Sleeping = 4,
Zombie = 5,
Dead = 6,
}Expand description
Thread state
Variants
Creating = 0
Thread is being created
Ready = 1
Thread is ready to run
Running = 2
Thread is currently running
Blocked = 3
Thread is blocked waiting
Sleeping = 4
Thread is sleeping
Zombie = 5
Thread has exited but not yet cleaned up (zombie)
Dead = 6
Thread is completely dead and can be cleaned up