pub struct TaskPtr(/* private fields */);Expand description
Safe wrapper for task pointer that implements Send + Sync
Safety: Task pointers are only accessed from within the scheduler which has its own synchronization mechanisms.
pub struct TaskPtr(/* private fields */);Safe wrapper for task pointer that implements Send + Sync
Safety: Task pointers are only accessed from within the scheduler which has its own synchronization mechanisms.