⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

init_with_bootstrap

Function init_with_bootstrap 

pub fn init_with_bootstrap(bootstrap_task: NonNull<Task>) -> KernelResult<()>
Initialize scheduler with bootstrap task

This is used during early boot to initialize the scheduler with a bootstrap task that will complete kernel initialization.