pub fn start() -> !Expand description
Start the scheduler
This transfers control to the scheduler, which will run the current task (bootstrap or idle) and never return.
pub fn start() -> !Start the scheduler
This transfers control to the scheduler, which will run the current task (bootstrap or idle) and never return.