pub struct AuditActiveFilter {
pub category_mask: u16,
pub min_severity: AuditSeverity,
}Expand description
Active filter controlling which events are accepted into the log.
Fields
category_mask: u16Bitmask of enabled categories (all bits set = log everything)
min_severity: AuditSeverityMinimum severity to log
Implementations
Sourceimpl AuditActiveFilter
impl AuditActiveFilter
Sourcepub const fn accept_all() -> Self
pub const fn accept_all() -> Self
Create a filter that accepts all events.
Sourcepub fn should_log(
&self,
category: AuditCategory,
severity: AuditSeverity,
) -> bool
pub fn should_log( &self, category: AuditCategory, severity: AuditSeverity, ) -> bool
Check if an event with the given category and severity should be logged.