Struct CapabilityTokenTarget
Source pub struct CapabilityTokenTarget;
Capability token fuzz target
Name of the fuzz target
Run one fuzzing iteration with the given input data
Reset state between iterations if needed
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.