Struct FuzzConfig
Source pub struct FuzzConfig {
pub max_input_size: usize,
pub max_iterations: u64,
pub seed: u64,
}
Fuzz runner configuration
Maximum input size in bytes
Number of iterations to run
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.