pub fn assign_user_roles_static(username: &'static str, roles: &[&'static str])Expand description
Map a user to a set of roles (zero-allocation version).
pub fn assign_user_roles_static(username: &'static str, roles: &[&'static str])Map a user to a set of roles (zero-allocation version).