pub fn lookup_transition(
source_type: &str,
target_type: &str,
class: &str,
) -> Option<&'static str>Expand description
Look up a domain transition.
Returns the new type if a transition rule matches.
pub fn lookup_transition(
source_type: &str,
target_type: &str,
class: &str,
) -> Option<&'static str>Look up a domain transition.
Returns the new type if a transition rule matches.