pub struct Role {
pub name: &'static str,
pub allowed_types: [&'static str; 16],
pub type_count: usize,
}Expand description
Role definition mapping a role name to allowed types.
Uses fixed-size array of &'static str to avoid heap allocations.
Fields
name: &'static strRole name (e.g. “admin_r”, “user_r”)
allowed_types: [&'static str; 16]Types this role is allowed to transition to
type_count: usizeNumber of active types in the array
Implementations
Sourceimpl Role
impl Role
Sourcepub fn from_types(name: &'static str, types: &[&'static str]) -> Self
pub fn from_types(name: &'static str, types: &[&'static str]) -> Self
Create a new role with allowed types from a slice.
Sourcepub fn allows_type(&self, type_name: &str) -> bool
pub fn allows_type(&self, type_name: &str) -> bool
Check if this role allows the given type.