⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

enable_ibrs

Function enable_ibrs 

pub fn enable_ibrs() -> Result<(), KernelError>
Enable IBRS (Indirect Branch Restricted Speculation).

After enabling, speculative targets of indirect branches executed in supervisor mode are restricted to those trained in supervisor mode.