pub fn flush_btb()Expand description
Flush the Branch Target Buffer (issue IBPB).
Should be called on context switches between different security domains (e.g., different processes) to prevent branch-target poisoning.
pub fn flush_btb()Flush the Branch Target Buffer (issue IBPB).
Should be called on context switches between different security domains (e.g., different processes) to prevent branch-target poisoning.