pub fn get_thread_canary(tid: u64) -> Option<u64>Expand description
Get the expected canary value for a thread.
Returns None if the subsystem is not initialized or the thread
has no registered canary.
pub fn get_thread_canary(tid: u64) -> Option<u64>Get the expected canary value for a thread.
Returns None if the subsystem is not initialized or the thread
has no registered canary.