⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

TpmResponseHeader

Struct TpmResponseHeader 

#[repr(C, packed(1))]
pub struct TpmResponseHeader { pub tag: u16, pub size: u32, pub response_code: u32, }
TPM Response Header (10 bytes, big-endian on wire)

Fields

tag: u16size: u32response_code: u32

Implementations

Source

impl TpmResponseHeader

pub fn parse(data: &[u8]) -> Option<Self>

Parse a response header from a byte slice (at least 10 bytes).

pub fn response_code(&self) -> TpmResponseCode

Decode the response code enum from the raw field.