pub fn hpack_static_find_name(name: &str) -> Option<usize>Expand description
Find the index of a header name in the HPACK static table.
pub fn hpack_static_find_name(name: &str) -> Option<usize>Find the index of a header name in the HPACK static table.