⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

try_get_driver_framework

Function try_get_driver_framework 

pub fn try_get_driver_framework() -> Option<&'static DriverFramework>
Try to get the global driver framework without panicking.

Returns None if the driver framework has not been initialized via init.