pub fn get_init_system() -> &'static InitSystemExpand description
Get the global init system.
Panics if the init system has not been initialized via init.
Prefer try_get_init_system in contexts where a panic is unacceptable.
pub fn get_init_system() -> &'static InitSystemGet the global init system.
Panics if the init system has not been initialized via init.
Prefer try_get_init_system in contexts where a panic is unacceptable.