⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

try_get_init_system

Function try_get_init_system 

pub fn try_get_init_system() -> Option<&'static InitSystem>
Try to get the global init system without panicking.

Returns None if the init system has not been initialized via init.