pub fn get_process_server() -> &'static ProcessServerExpand description
Get the global process server.
Panics if the process server has not been initialized via init.
Prefer try_get_process_server in contexts where a panic is unacceptable.
pub fn get_process_server() -> &'static ProcessServerGet the global process server.
Panics if the process server has not been initialized via init.
Prefer try_get_process_server in contexts where a panic is unacceptable.