⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

try_get_process_server

Function try_get_process_server 

pub fn try_get_process_server() -> Option<&'static ProcessServer>
Try to get the global process server without panicking.

Returns None if the process server has not been initialized via init.