pub fn get_shell() -> &'static ShellExpand description
Get the global shell.
Panics
Panics if the shell has not been initialized via init.
Prefer try_get_shell in contexts where a panic is unacceptable.
pub fn get_shell() -> &'static ShellGet the global shell.
Panics if the shell has not been initialized via init.
Prefer try_get_shell in contexts where a panic is unacceptable.