Struct GlobalState
Source pub struct GlobalState<T> { }
Safe global state with mutex (Rust 2024 compatible)
Create new uninitialized global state
Initialize the global state
Get reference with closure
Get mutable reference with closure
Try to get a reference (may fail if not initialized)
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.