pub fn get_thread_manager() -> &'static ThreadManagerExpand description
Get the global thread manager.
Panics if the thread manager has not been initialized via init.
Prefer try_get_thread_manager in contexts where a panic is unacceptable.
pub fn get_thread_manager() -> &'static ThreadManagerGet the global thread manager.
Panics if the thread manager has not been initialized via init.
Prefer try_get_thread_manager in contexts where a panic is unacceptable.