pub fn sleep_ms(ms: u64)Expand description
Sleep for a number of milliseconds
Uses timer-based sleep to avoid busy-waiting. The thread will yield to the scheduler while waiting for the sleep duration to elapse.
pub fn sleep_ms(ms: u64)Sleep for a number of milliseconds
Uses timer-based sleep to avoid busy-waiting. The thread will yield to the scheduler while waiting for the sleep duration to elapse.