⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

try_get_thread_manager

Function try_get_thread_manager 

pub fn try_get_thread_manager() -> Option<&'static ThreadManager>
Try to get the global thread manager without panicking.

Returns None if the thread manager has not been initialized via init.