⚠️ VeridianOS Kernel Documentation - This is low-level kernel code. All functions are unsafe unless explicitly marked otherwise. no_std

init_code_bytes

Function init_code_bytes 

pub fn init_code_bytes() -> &'static [u8]
Return the raw machine code for the init process.

This is the position-independent code that will be copied to a user-space page. It uses PC-relative addressing so it can run at any address.