Struct ShpcController
Source pub struct ShpcController {
pub slots: Vec<PciHotplugSlot>,
pub base_addr: u64,
pub enabled: bool,
}
Standard Hot-Plug Controller for conventional PCI hot-plug
Controller base address (MMIO)
Whether the controller is enabled
Create a new SHPC controller
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.