Struct DeviceMultiplexer
Source pub struct DeviceMultiplexer { }
Multiplexer for routing I/O and MMIO to registered device handlers
Create a new empty device multiplexer
SourceAvailable on crate feature alloc only.
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.