pub fn memory_fence()Expand description
Full memory fence – all reads and writes issued before this barrier are globally visible before any reads or writes issued after it.
- x86_64:
core::sync::atomic::fence(SeqCst)– MFENCE semantics. - AArch64:
dsb sy– Data Synchronization Barrier (full system). - RISC-V:
fence rw, rw– read/write ordering fence.