pub unsafe fn inl(port: u16) -> u32
Read a 32-bit dword from an x86_64 I/O port.
The caller must ensure port is a valid I/O port address for the intended device and that the device produces valid 32-bit reads.
port