pub unsafe fn inw(port: u16) -> u16
Read a 16-bit word from an x86_64 I/O port.
The caller must ensure port is a valid I/O port address for the intended device and that the device produces valid 16-bit reads.
port