pub unsafe fn outl(port: u16, value: u32)
Write a 32-bit dword to an x86_64 I/O port.
The caller must ensure port is a valid I/O port address for the intended device and that the device expects a 32-bit write.
port