pub unsafe fn outw(port: u16, value: u16)
Write a 16-bit word to an x86_64 I/O port.
The caller must ensure port is a valid I/O port address for the intended device and that the device expects a 16-bit write.
port