pub fn init()Expand description
Initialize KPTI with shadow page tables derived from the current CR3.
Must be called after the kernel page tables are fully set up.
pub fn init()Initialize KPTI with shadow page tables derived from the current CR3.
Must be called after the kernel page tables are fully set up.