pub fn rtc_interrupt_handler()Expand description
RTC interrupt handler (IRQ 8, vector 40 on PIC / remapped on APIC).
Acknowledges the interrupt by reading Register C, then dispatches the alarm callback if an alarm interrupt occurred (bit 5 of Register C).