pub fn per_cpu_data_ptr() -> *mut PerCpuDataExpand description
Get a mutable pointer to the per-CPU data.
Used to update kernel_rsp on context switch and to set up KernelGsBase
during init. The returned pointer is valid for the lifetime of the kernel.