pub fn tick()Expand description
Increment timer ticks (called from APIC timer interrupt handler at vector 48).
Increments the global tick counter and triggers a scheduler tick for
preemptive scheduling. Uses try_lock() on the scheduler to avoid
deadlock if the scheduler lock is already held (e.g., we interrupted
mid-schedule).