pub fn mp3_intensity_stereo(left: &mut [i32], right: &mut [i32], is_pos: u8)Expand description
Apply intensity stereo processing for a given scalefactor band
Intensity stereo encodes one channel and derives the other using a position parameter.
pub fn mp3_intensity_stereo(left: &mut [i32], right: &mut [i32], is_pos: u8)Apply intensity stereo processing for a given scalefactor band
Intensity stereo encodes one channel and derives the other using a position parameter.