pub fn render_glyph(
parser: &TtfParser<'_>,
ch: char,
pixel_size: u16,
) -> Result<GlyphBitmap, FontError>Expand description
Render a character to a grayscale bitmap at the given pixel size.
This is the main entry point for glyph rendering. It:
- Looks up the glyph ID from the character code via
cmap. - Parses the glyph outline from
glyf. - Rasterizes the outline to a bitmap.