pub struct PdfParser { /* private fields */ }Expand description
PDF file parser.
Implementations
Sourceimpl PdfParser
impl PdfParser
Sourcepub fn parse_header(&self) -> bool
pub fn parse_header(&self) -> bool
Parse the PDF header and verify the signature.
Sourcepub fn parse_xref_table(&mut self) -> bool
pub fn parse_xref_table(&mut self) -> bool
Parse the cross-reference table.
Looks for startxref near the end of the file, then parses the xref
section.
Sourcepub fn parse_object(&mut self, obj_num: u32) -> Option<PdfObject>
pub fn parse_object(&mut self, obj_num: u32) -> Option<PdfObject>
Parse a single object from the data at the given offset.
Sourcepub fn xref_count(&self) -> usize
pub fn xref_count(&self) -> usize
Get the number of xref entries.