pub struct WlBuffer {
pub id: u32,
pub pool_id: u32,
pub offset: u32,
pub width: u32,
pub height: u32,
pub stride: u32,
pub format: PixelFormat,
pub released: bool,
}Expand description
A buffer object referencing pixel data within a WlShmPool.
Fields
id: u32Buffer object ID
pool_id: u32Owning pool ID
offset: u32Byte offset into the pool
width: u32Width in pixels
height: u32Height in pixels
stride: u32Bytes per row
format: PixelFormatPixel format
released: boolWhether the compositor has released this buffer back to the client
Implementations