pub struct OutputMode {
pub width: u32,
pub height: u32,
pub refresh_mhz: u32,
pub preferred: bool,
pub current: bool,
}Expand description
A display mode supported by an output.
Each output can support multiple modes (resolutions and refresh rates).
Exactly one mode should be marked as current, and one as preferred.
Fields
width: u32Horizontal resolution in pixels
height: u32Vertical resolution in pixels
refresh_mhz: u32Refresh rate in millihertz (e.g., 60000 = 60Hz)
preferred: boolWhether this is the preferred (native) mode
current: boolWhether this is the currently active mode
Implementations
Sourceimpl OutputMode
impl OutputMode
Sourcepub fn new_current_preferred(width: u32, height: u32, refresh_mhz: u32) -> Self
pub fn new_current_preferred(width: u32, height: u32, refresh_mhz: u32) -> Self
Create a mode marked as both current and preferred.
Sourcepub fn pixel_count(&self) -> u64
pub fn pixel_count(&self) -> u64
Pixel count for this mode.