pub fn parse_message(
data: &[u8],
) -> Result<(WaylandMessage, usize), WaylandError>Expand description
Parse a single Wayland wire-protocol message from the front of data.
Returns the parsed message and the number of bytes consumed so that the caller can advance through a buffer containing multiple messages.