pub struct DynamicLinkerInfo {
pub interp_path: String,
pub interp_base: u64,
pub interp_entry: u64,
pub aux_vector: Vec<AuxVecEntry>,
}Expand description
Information required to set up the dynamic linker for a binary.
Fields
interp_path: StringPath to the interpreter (e.g., /lib/ld-linux.so.2).
interp_base: u64Base address at which the interpreter was loaded.
interp_entry: u64Entry point of the interpreter.
aux_vector: Vec<AuxVecEntry>Auxiliary vector to place on the initial user stack.