pub struct PtySlaveNode { /* private fields */ }Expand description
VfsNode adapter for the slave side of a PTY.
Reading from this node returns bytes that the master has written (i.e. keyboard input forwarded to the shell). Writing to this node sends bytes to the master’s output buffer (the program’s output visible in the terminal emulator).
Implementations