pub fn deliver_signal(target_pid: u64, signum: u32, sender_pid: u32)Expand description
Deliver a signal to all signalfds of a given process that have the signal in their mask.
Called from the kernel’s signal delivery path.
pub fn deliver_signal(target_pid: u64, signum: u32, sender_pid: u32)Deliver a signal to all signalfds of a given process that have the signal in their mask.
Called from the kernel’s signal delivery path.