pub fn getxattr(inode: u64, name: &str) -> Result<Vec<u8>, KernelError>Expand description
Retrieve the value of an extended attribute.
Returns the attribute value as a byte vector, or an error if the inode or attribute name does not exist.
pub fn getxattr(inode: u64, name: &str) -> Result<Vec<u8>, KernelError>Retrieve the value of an extended attribute.
Returns the attribute value as a byte vector, or an error if the inode or attribute name does not exist.