pub fn flush()Expand description
Blit all pending changes to the hardware framebuffer.
Call this after a logical group of output is complete (e.g., after a command finishes, after printing the prompt, after echoing a keystroke). This is the ONLY code path that writes to MMIO.