pub fn transfer_capability(
msg: &Message,
sender_cap_space: &CapabilitySpace,
receiver_pid: ProcessId,
) -> Result<Option<CapabilityToken>>Expand description
Transfer a capability through an IPC message
This function handles the delegation of a capability from the sender to the receiver of an IPC message.