pub struct PageFaultInfo {
pub faulting_address: u64,
pub reason: PageFaultReason,
pub was_write: bool,
pub was_user_mode: bool,
pub instruction_pointer: u64,
}Expand description
Information about a page fault collected by the architecture trap handler.
Fields
faulting_address: u64The virtual address that caused the fault.
reason: PageFaultReasonWhy the fault occurred.
was_write: boolWhether the access was a write (true) or read (false).
was_user_mode: boolWhether the fault occurred while executing in user mode.
instruction_pointer: u64Instruction pointer at the time of the fault.