pub fn map_physical_region_user(
phys_addr: u64,
size: usize,
) -> Result<usize, SyscallError>Expand description
Map a physical memory region into the current process’s user-space address space.
Allocates a virtual address range via the process’s VAS mmap region and maps the given physical frames into it. Used for framebuffer mmap.
Returns the user-space virtual address of the mapping.