pub struct CubicController { /* private fields */ }Expand description
TCP Cubic congestion controller (RFC 8312).
Cubic uses a cubic function of elapsed time since the last congestion event to set the congestion window, providing better bandwidth utilization on high-BDP networks than Reno while remaining TCP-friendly on low-BDP paths.
Implementations
Sourceimpl CubicController
impl CubicController
Sourcepub fn state(&self) -> &CongestionState
pub fn state(&self) -> &CongestionState
Access the underlying congestion state.
Sourcepub fn phase(&self) -> CongestionPhase
pub fn phase(&self) -> CongestionPhase
Return the current congestion phase.
Sourcepub fn dup_ack_count(&self) -> u32
pub fn dup_ack_count(&self) -> u32
Return the duplicate ACK count.