pub struct FirewallTable {
pub table_type: ChainType,
pub chains: Vec<Chain>,
}Expand description
A firewall table containing chains for a specific purpose
Fields
table_type: ChainTypeTable type
chains: Vec<Chain>Chains belonging to this table
Implementations
Sourceimpl FirewallTable
impl FirewallTable
Sourcepub fn new_filter() -> Self
pub fn new_filter() -> Self
Create a new filter table with default INPUT, FORWARD, OUTPUT chains
Sourcepub fn new_mangle() -> Self
pub fn new_mangle() -> Self
Create a new mangle table with all five hook points
Sourcepub fn get_chain_mut(&mut self, name: &str) -> Option<&mut Chain>
pub fn get_chain_mut(&mut self, name: &str) -> Option<&mut Chain>
Find a mutable chain by name
Sourcepub fn chains_for_hook(&self, hook: HookPoint) -> Vec<&Chain>
pub fn chains_for_hook(&self, hook: HookPoint) -> Vec<&Chain>
Get all chains for a specific hook point