pub fn build_dest_unreachable(
src: &Ipv6Address,
dst: &Ipv6Address,
code: u8,
invoking_packet: &[u8],
) -> Vec<u8>Expand description
Build a Destination Unreachable message.
invoking_packet should be the start of the invoking IPv6 packet
(as much as possible without exceeding the minimum MTU).