pub fn decode_dns_name(
buf: &[u8],
offset: usize,
) -> Result<(String, usize), MdnsError>Expand description
Decode a DNS wire-format name from a buffer at the given offset.
Returns the decoded name and the number of bytes consumed from offset.