pub struct SackBlock {
pub left_edge: u32,
pub right_edge: u32,
}Expand description
A single SACK block representing a contiguous range of received bytes.
left_edge is the first sequence number in the block (inclusive).
right_edge is one past the last sequence number (exclusive).
Fields
left_edge: u32right_edge: u32Implementations