pub fn check_compatibility(
deps: &[(String, License)],
) -> Result<(), Vec<LicenseConflict>>Expand description
Check all license pairs in a dependency list for compatibility.
Returns Ok(()) if all pairs are compatible, or Err with a list of
conflicts found.