pub fn apply_delta(
old: &[u8],
delta: &BinaryDelta,
) -> Result<Vec<u8>, KernelError>Expand description
Apply a binary delta to the source data, producing the target.
Returns an error if a Copy operation references out-of-bounds source data.