pub struct SdkPackageSpec {
pub manifest: SdkManifest,
pub header_paths: Vec<String>,
pub lib_paths: Vec<String>,
pub tool_paths: Vec<String>,
pub doc_paths: Vec<String>,
}Expand description
Full specification for building an SDK package, combining the manifest with the paths to include.
Fields
manifest: SdkManifestThe SDK manifest describing version, targets, and components.
header_paths: Vec<String>Paths to header files to include.
lib_paths: Vec<String>Paths to library files to include.
tool_paths: Vec<String>Paths to tool binaries to include.
doc_paths: Vec<String>Paths to documentation files to include.
Implementations
Sourceimpl SdkPackageSpec
impl SdkPackageSpec
Sourcepub fn new(manifest: SdkManifest) -> Self
pub fn new(manifest: SdkManifest) -> Self
Create a new package spec from a manifest with empty path lists.
Sourcepub fn add_header_path(&mut self, path: &str)
pub fn add_header_path(&mut self, path: &str)
Add a header file path.
Sourcepub fn add_lib_path(&mut self, path: &str)
pub fn add_lib_path(&mut self, path: &str)
Add a library file path.
Sourcepub fn add_tool_path(&mut self, path: &str)
pub fn add_tool_path(&mut self, path: &str)
Add a tool binary path.
Sourcepub fn add_doc_path(&mut self, path: &str)
pub fn add_doc_path(&mut self, path: &str)
Add a documentation file path.