pub fn run_package_tests(package: &str) -> Vec<TestResult>Expand description
Run all tests defined for a package.
Looks up test definitions for the given package name and executes them
through a TestRunner. Returns an empty list if the package has no tests.