pub fn clear_boot_current()Expand description
Clear the boot-launched process tracking.
Called from the bootstrap wrapper after the user process exits and control returns to the kernel bootstrap code.
pub fn clear_boot_current()Clear the boot-launched process tracking.
Called from the bootstrap wrapper after the user process exits and control returns to the kernel bootstrap code.