pub struct CondVar { /* private fields */ }
Condition variable implementation
Create a new condition variable
Wait on condition variable.
Returns Err if the mutex is not held by the caller. The caller must hold the mutex before calling wait, as required by the standard condition variable protocol.
Err
wait
Signal one waiting thread
Signal all waiting threads
alloc
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U