pub struct Stack {
pub base: usize,
pub size: usize,
pub sp: AtomicUsize,
pub phys_frame: AtomicU64,
pub phys_page_count: AtomicUsize,
}Expand description
Stack information
Fields
base: usizeBase address (lowest address, virtual)
size: usizeSize in bytes
sp: AtomicUsizeCurrent stack pointer
phys_frame: AtomicU64Physical frame number of the contiguous allocation from the frame allocator. Stored so cleanup can free the frames without walking page tables. Zero means no physical frames are owned by this Stack (e.g., user stacks whose frames are managed by the VAS).
phys_page_count: AtomicUsizeNumber of physical pages owned by this stack (for free_frames).