pub fn notify_parent(child_pid: ProcessId, status: WaitStatus)Expand description
Notify a parent process that a child has changed state.
Called from the child exit path to wake the parent if it is blocked in
waitpid. Also sends SIGCHLD to the parent.