pub fn init_with_bootstrap(bootstrap_task: NonNull<Task>) -> KernelResult<()>Expand description
Initialize scheduler with bootstrap task
This is used during early boot to initialize the scheduler with a bootstrap task that will complete kernel initialization.