pub fn load_policy(policy_text: &'static str) -> Result<(), KernelError>Expand description
Load a policy from text.
Parses the policy text and adds all rules, transitions, roles, and user mappings to the active policy database.
The input MUST have 'static lifetime (e.g., a const string literal).