pub fn set_thread_canary(tid: u64, value: u64) -> Result<(), KernelError>Expand description
Register a canary value for a thread.
Associates the given canary value with thread tid in the global
canary table. If the thread already has a canary, it is replaced.
Returns Err if the canary subsystem is not initialized.