pub fn try_get_driver_framework() -> Option<&'static DriverFramework>Expand description
Try to get the global driver framework without panicking.
Returns None if the driver framework has not been initialized via
init.
pub fn try_get_driver_framework() -> Option<&'static DriverFramework>Try to get the global driver framework without panicking.
Returns None if the driver framework has not been initialized via
init.