pub fn try_get_init_system() -> Option<&'static InitSystem>Expand description
Try to get the global init system without panicking.
Returns None if the init system has not been initialized via init.
pub fn try_get_init_system() -> Option<&'static InitSystem>Try to get the global init system without panicking.
Returns None if the init system has not been initialized via init.