pub fn try_get_process_server() -> Option<&'static ProcessServer>Expand description
Try to get the global process server without panicking.
Returns None if the process server has not been initialized via init.
pub fn try_get_process_server() -> Option<&'static ProcessServer>Try to get the global process server without panicking.
Returns None if the process server has not been initialized via init.