pub fn clear_cpu_slots(cpu_id: u8)Expand description
Clear all hazard pointer slots for a given CPU.
Called during CPU shutdown or thread exit to release all protections.
pub fn clear_cpu_slots(cpu_id: u8)Clear all hazard pointer slots for a given CPU.
Called during CPU shutdown or thread exit to release all protections.