pub fn synchronize_rcu()Expand description
Wait for all pre-existing RCU read-side critical sections to complete.
After this function returns, it is safe to free memory that was visible to readers before the call. This is the synchronous grace period wait.
On a single-CPU system, a single quiescent state check is sufficient. On SMP, we spin until all CPUs have reported a quiescent state.