pub fn try_get_thread_manager() -> Option<&'static ThreadManager>Expand description
Try to get the global thread manager without panicking.
Returns None if the thread manager has not been initialized via init.
pub fn try_get_thread_manager() -> Option<&'static ThreadManager>Try to get the global thread manager without panicking.
Returns None if the thread manager has not been initialized via init.