pub fn init_code_bytes() -> &'static [u8]Expand description
Return the raw machine code for the init process.
This is the position-independent code that will be copied to a user-space page. It uses PC-relative addressing so it can run at any address.