pub struct CapInvariantChecker;Expand description
Capability invariant checker
Implementations
Sourceimpl CapInvariantChecker
impl CapInvariantChecker
Sourcepub fn verify_non_forgery(
space: &CapSpaceModel,
random_token: u64,
) -> Result<(), CapModelError>
pub fn verify_non_forgery( space: &CapSpaceModel, random_token: u64, ) -> Result<(), CapModelError>
Verify non-forgery: capabilities can only be created through the kernel API
A random u64 should not match any valid capability in the space.
Sourcepub fn verify_rights_monotonicity(
space: &CapSpaceModel,
) -> Result<(), CapModelError>
pub fn verify_rights_monotonicity( space: &CapSpaceModel, ) -> Result<(), CapModelError>
Verify rights monotonicity: derived capabilities have subset of parent rights
Sourcepub fn verify_revocation_completeness(
space: &CapSpaceModel,
revoked_token: u64,
) -> Result<(), CapModelError>
pub fn verify_revocation_completeness( space: &CapSpaceModel, revoked_token: u64, ) -> Result<(), CapModelError>
Verify revocation completeness: revoking a parent removes all children
Sourcepub fn verify_generation_integrity(
space: &CapSpaceModel,
old_gen: u32,
) -> Result<(), CapModelError>
pub fn verify_generation_integrity( space: &CapSpaceModel, old_gen: u32, ) -> Result<(), CapModelError>
Verify generation integrity: bumping generation invalidates old tokens