pub enum OciLifecycleState {
Creating,
Created,
Running,
Stopped,
}Expand description
OCI container lifecycle states per the runtime-spec.
Variants
Creating
Container bundle loaded, namespaces created, but process not started.
Created
Container created but user process not yet started (post-create hooks ran).
Running
Container process is running.
Stopped
Container process has exited.