pub struct SeccompFilter {
pub instructions: Vec<BpfInstruction>,
pub inherit_on_fork: bool,
pub filter_id: u64,
}Expand description
A seccomp BPF filter program.
Fields
instructions: Vec<BpfInstruction>BPF instructions.
inherit_on_fork: boolWhether this filter should be inherited on fork.
filter_id: u64Filter ID for tracking.
Implementations
Sourceimpl SeccompFilter
impl SeccompFilter
Sourcepub fn push(&mut self, insn: BpfInstruction)
pub fn push(&mut self, insn: BpfInstruction)
Add an instruction to the filter.
Sourcepub fn validate(&self) -> Result<(), KernelError>
pub fn validate(&self) -> Result<(), KernelError>
Validate the filter program.
Sourcepub fn evaluate(&self, data: &SeccompData) -> u32
pub fn evaluate(&self, data: &SeccompData) -> u32
Execute the filter against a seccomp_data structure. Returns the action (SeccompAction value | errno).
Sourcepub fn deny_syscalls(arch: u32, denied: &[u32], errno_val: u16) -> Self
pub fn deny_syscalls(arch: u32, denied: &[u32], errno_val: u16) -> Self
Build a filter that checks architecture and denies a set of syscall numbers.
Sourcepub fn allow_syscalls(arch: u32, allowed: &[u32]) -> Self
pub fn allow_syscalls(arch: u32, allowed: &[u32]) -> Self
Build a filter that only allows a whitelist of syscalls.